OC.L10N.register(
    "settings",
    {
    "Private" : "Soukromé",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Viditelné pouze lidem, se kterými nalezena shoda začleněním přes telefonní číslo prostřednictvím Talk na mobilním telefonu",
    "Local" : "Místní",
    "Only visible to people on this instance and guests" : "Viditelné pouze lidem na této instanci a hostům",
    "Federated" : "Federované",
    "Only synchronize to trusted servers" : "Synchronizovat pouze s důvěryhodnými servery",
    "Published" : "Zveřejněno",
    "Synchronize to trusted servers and the global and public address book" : "Synchronizovat s důvěryhodnými servery a globálním a veřejným adresářem kontaktů",
    "Verify" : "Ověřit",
    "Verifying …" : "Ověřování…",
    "Unable to change password" : "Heslo nejde změnit",
    "Very weak password" : "Velmi snadno prolomitelné heslo",
    "Weak password" : "Snadno prolomitelné heslo",
    "So-so password" : "Středně odolné heslo",
    "Good password" : "Dobré heslo",
    "Strong password" : "Odolné heslo",
    "Groups" : "Skupiny",
    "Group list is empty" : "Seznam skupin je prázdný.",
    "Unable to retrieve the group list" : "Nedaří se získat seznam skupiny",
    "{actor} added you to group {group}" : "{actor} vás přidal(a) do skupiny {group}",
    "You added {user} to group {group}" : "Přidali jste {user} do skupiny {group}",
    "{actor} added {user} to group {group}" : "{actor} přidal(a) {user} do skupiny {group}",
    "An administrator added you to group {group}" : "Správce vás přidal do skupiny {group}",
    "An administrator added {user} to group {group}" : "Správce přidal {user} do skupiny {group}",
    "{actor} removed you from group {group}" : "{actor} vás odebral(a) ze skupiny {group}",
    "You removed {user} from group {group}" : "Odebrali jste {user} ze skupiny {group}",
    "{actor} removed {user} from group {group}" : "{actor} odebral(a) {user} ze skupiny {group}",
    "An administrator removed you from group {group}" : "Správce vás odebral ze skupiny {group}",
    "An administrator removed {user} from group {group}" : "Správce odebral {user} ze skupiny {group}",
    "Your <strong>group memberships</strong> were modified" : "Vaše <strong>členství ve skupinách</strong> byla upravena",
    "{actor} changed your password" : "{actor} změnil(a) vaše heslo",
    "You changed your password" : "Změnili jste si své heslo",
    "Your password was reset by an administrator" : "Vaše heslo bylo resetováno správcem",
    "Your password was reset" : "Vaše heslo bylo nastaveno znovu",
    "{actor} changed your email address" : "{actor} změnil(a) vaši e-mailovou adresu",
    "You changed your email address" : "Změnili jste si svou e-mailovou adresu",
    "Your email address was changed by an administrator" : "Vaše e-mailová adresa byla změněna správcem",
    "You created app password \"{token}\"" : "Vytvořili jste heslo pro aplikaci „{token}“",
    "An administrator created app password \"{token}\"" : "Správce vytvořil heslo pro aplikaci „{token}“",
    "You deleted app password \"{token}\"" : "Smazali jste heslo pro aplikaci „{token}“",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Přejmenovali jste heslo aplikace „{token}“ na „{newToken}“",
    "You granted filesystem access to app password \"{token}\"" : "Udělili jste přístup k souborovému systému aplikaci, používající heslo „{token}“",
    "You revoked filesystem access from app password \"{token}\"" : "Zrušili jste přístup k souborovému systému pro aplikaci, využívající heslo „{token}“",
    "Security" : "Zabezpečení",
    "You successfully logged in using two-factor authentication (%1$s)" : "Úspěšně jste se přihlásili pomocí dvoufázového ověření (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Pokus o přihlášení s použitím dvoufázové autentizace se nezdařil (%1$s)",
    "Remote wipe was started on %1$s" : "Vymazání na dálku spuštěno na %1$s",
    "Remote wipe has finished on %1$s" : "Vymazání na dálku bylo na %1$s dokončeno",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Vaše <strong>heslo</strong> nebo <strong>e-mail</strong> bylo změněno",
    "Could not remove app." : "Aplikaci se nedaří odebrat.",
    "Could not update app." : "Aplikaci se nedaří aktualizovat.",
    "Wrong password" : "Nesprávné heslo",
    "Unable to change personal password" : "Osobní heslo se nedaří změnit",
    "Saved" : "Uloženo",
    "No user supplied" : "Nebyl uveden uživatel",
    "Unable to change password. Password too long." : "Heslo se nedaří změnit – je příliš dlouhé.",
    "Authentication error" : "Chyba přihlášení",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Zadejte správcovské heslo pro obnovu, jinak budou všechna uživatelská data ztracena.",
    "Wrong admin recovery password. Please check the password and try again." : "Chybné heslo správce pro obnovu. Překontrolujte správnost jeho zadání a zkuste to znovu.",
    "Backend does not support password change, but the user's encryption key was updated." : "Podpůrná vrstva nepodporuje změnu hesla, ale uživatelův šifrovací klíč byl aktualizován.",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "Instalovat a aktualizovat aplikace prostřednictvím katalogu nebo federované cloudové sdílení",
    "Federated Cloud Sharing" : "Federované cloudové sdílení",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL používá zastaralou verzi %1$s (%2$s). Aktualizujte operační systém jinak funkce jako například %3$s nebudou fungovat spolehlivě.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Nelze zjistit, zda je verze TLS cURL zastaralá nebo ne, protože během požadavku HTTPS na https://nextcloud.com došlo k chybě. Další podrobnosti najdete v souboru se záznamy událostí v Nextcloud.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP modul OPcache není načten. Pro lepší výkon je doporučeno načíst ho do vaší PHP instalace.",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache je vypnuté. Pro lepší výkon je doporučeno přidat do nastavení PHP volbu <code>opcache.enable=1</code>.",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache je nastaveno tak, aby odebíralo komentáře kódu. Pokud je OPcache zapnuté, pak aby Nextcloud fungoval, je třeba, aby bylo nastaveno také <code>opcache.save_comments=1</code>.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Pro Nextcloud nemáte zpřístupněno používání aplikačního program. rozhraní (API) OPcache. Pokud je OPcache zapnuté, je velmi doporučováno zahrnout veškeré složky s Nextcloud do <code>opcache.restrict_api</code> nebo toto nastavení zrušit a vypnout tak omezení k OPcache API. Zabráníte tak chybám při aktualizacím jádra Nextcloud či aplikací.",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Pro Nextcloud nemáte zpřístupněno používání aplikačního program. rozhraní (API) OPcache. Je silně doporučováno zahrnout veškeré složky s Nextcloud do <code>opcache.restrict_api</code> nebo toto nastavení zrušit a vypnout tak omezení k OPcache API. Zabráníte tak chybám při aktualizacím jádra Nextcloud či aplikací.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Je téměř vyčerpán nejvyšší umožněný počet klíčů v OPcache. Aby bylo zajištěno, že se do mezipaměti vejdou veškeré skripty, je doporučeno přidat do nastavení PHP volbu <code>opcache.max_accelerated_files</code> s hodnotou vyšší než <code>%s</code>.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "Vnitřní vyrovnávací paměť OPcache je téměř zaplněná. Aby bylo zajištěno, že se do mezipaměti vejdou veškeré skripty, je doporučeno přidat do nastavení PHP volbu <code>opcache.memory_consumption</code> s hodnotou vyšší než <code>%s</code>.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "Vnitřní vyrovnávací paměť OPcache pro řetězce je téměř zaplněná. Aby bylo zajištěno, že ukládání řetězců do mezipaměti bude skutečně prováděno, je doporučeno přidat do nastavení PHP volbu <code>opcache.interned_strings_buffer</code> s hodnotou vyšší než <code>%s</code>.",
    "Invalid SMTP password." : "Neplatné heslo pro SMTP.",
    "Email setting test" : "Zkouška nastavení e-mailu",
    "Well done, %s!" : "Úspěšně nastaveno, %s!",
    "If you received this email, the email configuration seems to be correct." : "Pokud přišel tento e-mail, nastavení pro odesílání e-mailů se zdá být v pořádku.",
    "Email could not be sent. Check your mail server log" : "E-mail se nepodařilo odeslat. Podívejte se do záznamu událostí (log) svého e-mailového serveru.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Při odesílání e-mailu nastala chyba – překontrolujte nastavení. (Chyba: %s)",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Aby bylo možné odesílat zkušební e-maily je třeba, abyste si nejprve nastavili svou e-mailovou adresu. To učiníte v %s.",
    "Invalid user" : "Neplatný uživatel",
    "Invalid mail address" : "Neplatná e-mailová adresa",
    "Settings saved" : "Nastavení uložena",
    "Unable to change full name" : "Nedaří se změnit celé jméno",
    "Unable to change email address" : "Nepodařilo se změnit e-mailovou adresu",
    "Unable to set invalid phone number" : "Do nastavení zadáno neplatné telefonní číslo",
    "Unable to set invalid website" : "Nelze nastavit neplatnou webovou stránku",
    "Some account data was invalid" : "Některé údaje v účtu nejsou platné",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Pokud chcete ověřit váš Twitter účet, napište následující tweet (ujistěte se, že ho zasíláte bez zalomení řádků):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Pro ověřování vašich webových stránek uložte následující obsah v kořenovém adresáři webové prezentace v umístění „.well-known/CloudIdVerificationCode.txt“ (ujistěte se, že byl text vložen jako jediný řádek)",
    "%1$s changed your password on %2$s." : "%1$s změnil(a) vaše heslo na %2$s.",
    "Your password on %s was changed." : "Vaše heslo na %s bylo změněno.",
    "Your password on %s was reset by an administrator." : "Vaše heslo na %s bylo resetováno správcem.",
    "Your password on %s was reset." : "Vaše heslo na %s bylo nastaveno znovu.",
    "Password for %1$s changed on %2$s" : "Heslo pro %1$s na %2$s změněno ",
    "Password changed for %s" : "Heslo změněno pro %s",
    "If you did not request this, please contact an administrator." : "Pokud jste o toto nežádali, obraťte se na správce.",
    "Your email address on %s was changed." : "Vaše e-mailová adresa na %s byla změněna.",
    "Your email address on %s was changed by an administrator." : "Vaše e-mailová adresa na %s byla změněna správcem.",
    "Email address for %1$s changed on %2$s" : "E-mailová adresa pro %1$s se na %2$s změnila",
    "Email address changed for %s" : "E-mailová adresa pro %s byla změněna",
    "The new email address is %s" : "Nová e-mailová adresa je %s",
    "Your %s account was created" : "Váš %s účet byl vytvořen",
    "Welcome aboard" : "Vítejte na palubě",
    "Welcome aboard %s" : "Vítejte na palubě, %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Vítejte ve svém %s účtu, můžete vkládat, chránit a sdílet svoje data.",
    "Your username is: %s" : "Vaše uživatelské jméno je: %s",
    "Set your password" : "Nastavte si své heslo",
    "Go to %s" : "Jít na %s",
    "Install Client" : "Nainstalovat klienta",
    "Logged in user must be a subadmin" : "Je třeba, aby přihlášený uživatel byl dílčím správcem",
    "Apps" : "Aplikace",
    "Settings" : "Nastavení",
    "Personal" : "Osobní",
    "Administration" : "Správa",
    "Additional settings" : "Další nastavení",
    "Administration privileges" : "Oprávnění ke správě",
    "Groupware" : "Software pro podporu spolupráce",
    "Overview" : "Přehled",
    "Basic settings" : "Základní nastavení",
    "Sharing" : "Sdílení",
    "Availability" : "Dostupnost",
    "Personal info" : "Osobní údaje",
    "Mobile & desktop" : "Mobilní a desktop",
    "Email server" : "E-mailový server",
    "Security & setup warnings" : "Varování ohledně zabezpečení a nastavení",
    "Background jobs" : "Úlohy na pozadí",
    "Create" : "Vytvořit",
    "Change" : "Změnit",
    "Delete" : "Smazat",
    "Reshare" : "Sdílet dál dalším",
    "Unlimited" : "Neomezeně",
    "Verifying" : "Ověřuje se",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Úloha na pozadí čeká na kontrolu uživatelských importovaných SSL certifikátů. Zkuste to prosím později.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Nacházejí se zde některé SSL certifikáty, importované uživatelem, které se už s Nextcloud 21 nepoužívají. Lze je naimportovat v příkazovém řádku pomocí příkazu „occ security:certificates:import“. Popisy jejich umístění v adresáři s daty jsou uvedeny níže.",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Nalezeny neplatné UUID identifikátory uživatelů nebo skupin. Zkontrolujte svá nastavení „Přebít zjišťování UUID identifikátorů“ v části pro odborníky nastavení pro LDAP a identifikátory pak zaktualizujte příkazem „ldap:update-uuid“.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Je zapnutý starý formát šifrování na straně serveru. Je doporučeno toto vypnout.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Je používána verze MariaDB „%s“. Nextcloud 21 a novější už tuto verzi nepodporuje a vyžaduje MariaDB 10.2 nebo novější.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Je používána verze MySQL „%s“. Nextcloud 21 a novější už tuto verzi nepodporuje a vyžaduje MySQL 8.0 nebo MariaDB 10.2 a novější.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Je používána verze PostgreSQL „%s“. Nextcloud 21 a novější už tuto verzi nepodporuje a vyžaduje PostgreSQL 9.6 nebo novější.",
    "Profile information" : "Informace o profilu",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profilový obrázek, celé jméno, e-mailová adresa, telefonní číslo, adresa, webové stránky, Twitter, organizace, role, úvod, životopis a to, zda je profil zapnutý",
    "Nextcloud settings" : "Nastavení Nextcloud",
    "Here you can decide which group can access certain sections of the administration settings." : "Zde je možné rozhodnout, které skupiny mohou přistupovat k určitým nastavením správy.",
    "None" : "Žádné",
    "Unable to modify setting" : "Nastavení se nedaří změnit",
    "Two-Factor Authentication" : "Dvoufázové ověření",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dvoufázové ověřování je možné vynutit pro všechny uživatele a konkrétní skupiny. Pokud nemají nastaveného poskytovatele dvoufázového ověřování, nebudou se moci přihlásit do systému.",
    "Enforce two-factor authentication" : "Vynutit dvoufázové ověřování",
    "Limit to groups" : "Omezit na skupiny",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Vynucení dvoufázového ověřování je možné nastavit pouze pro určité skupiny.",
    "Two-factor authentication is enforced for all members of the following groups." : "Dvoufázové ověřování je vynucováno pro všechny členy následujících skupin.",
    "Enforced groups" : "Vynucené skupiny",
    "Two-factor authentication is not enforced for members of the following groups." : "Dvoufázové ověřování není vynucováno pro členy následujících skupin.",
    "Excluded groups" : "Vynechané skupiny",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Když jsou skupiny vybrány/vynechány, je pro zjišťování zda je uživateli vynuceno dvoufázové (2FA) ověřování použita následující logika: Pokud nejsou vybrány žádné skupiny, je 2FA zapnuto pro všechny kromě členů vynechaných skupin. Pokud jsou nějaké skupiny vybrány, je 2FA zapnuto pro všechny jejich členy. Pokud je uživatel členem jak vybrané, tak vynechané skupiny, pak má ta vybraná přednost a 2FA je vynuceno.",
    "Save changes" : "Uložit změny",
    "All" : "Vše",
    "Limit app usage to groups" : "Omezit používání aplikace na skupiny",
    "No results" : "Žádné výsledky",
    "Update to {version}" : "Aktualizovat na {version}",
    "Remove" : "Odstranit",
    "Disable" : "Vypnout",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Tato aplikace nemá nastavený žádný požadavek na minimální verzi Nextcloud. To v budoucnu bude hodnoceno jako chyba.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Tato aplikace nemá nastavenou žádnou nejvyšší podporovanou verzi Nextcloud. To v budoucnu bude hodnoceno jako chyba.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Tuto aplikaci nelze nainstalovat, protože nejsou splněny následující závislosti:",
    "View in store" : "Zobrazit v katalogu",
    "Visit website" : "Navštívit webovou stránku",
    "Report a bug" : "Nahlásit chybu",
    "User documentation" : "Dokumentace pro uživatele",
    "Admin documentation" : "Dokumentace pro správce",
    "Developer documentation" : "Dokumentace pro vývojáře",
    "This app is supported via your current Nextcloud subscription." : "Tato aplikace je podporována prostřednictvím vašeho stávajícího předplatného podpory Nextcloud.",
    "Supported" : "Podporováno",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Doporučované aplikace jsou vyvíjeny komunitou. Jsou propojeny se zbytkem Nextcloud a připraveny na produkční nasazení.",
    "Featured" : "Doporučené",
    "Update to {update}" : "Aktualizovat na {update}",
    "All apps are up-to-date." : "Všechny aplikace jsou aktuální",
    "Results from other categories" : "Výsledky z ostatních kategorií",
    "No apps found for your version" : "Nebyly nalezeny aplikace pro vaši verzi",
    "Disable all" : "Zakázat vše",
    "Enable all" : "Zapnout vše",
    "_%n app has an update available_::_%n apps have an update available_" : ["pro %n aplikaci je k dispozici aktualizace","pro %n aplikace jsou k dispozici aktualizace","pro %n aplikací jsou k dispozici aktualizace","pro %n aplikace jsou k dispozici aktualizace"],
    "_Update_::_Update all_" : ["Aktualizovat","Aktualizovat vše","Aktualizovat vše","Aktualizovat vše"],
    "Marked for remote wipe" : "Označeno k vymazání obsahu na dálku",
    "Device settings" : "Nastavení zařízení",
    "Allow filesystem access" : "Povolit přístup k souborovému systému",
    "Rename" : "Přejmenovat",
    "Revoke" : "Odvolat",
    "Wipe device" : "Vymazat obsah zařízení",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Odstranění tohoto tokenu může zabránit vymazání obsahu přístroje, pokud nebyl proces vymazání do teď zahájen.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome pro Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName} aplikace pro iOS",
    "{productName} Android app" : "{productName} aplikace pro Android",
    "{productName} Talk for iOS" : "{productName} Talk pro iOS",
    "{productName} Talk for Android" : "{productName} Talk pro Android",
    "Sync client - {os}" : "Synchronizační klient – {os}",
    "This session" : "Toto sezení",
    "Device" : "Přístroj",
    "Last activity" : "Poslední aktivita",
    "Devices & sessions" : "Zařízení a sezení",
    "Web, desktop and mobile clients currently logged in to your account." : "Weboví, desktopoví a mobilní klienti aktuálně přihlášení k vašemu účtu.",
    "Do you really want to wipe your data from this device?" : "Opravdu chcete vymazat svá data z tohoto zařízení?",
    "Confirm wipe" : "Potvrdit vymazání",
    "Error while creating device token" : "Chyba při vytváření tokenu přístroje",
    "Error while updating device token scope" : "Chyba při aktualizaci rozsahu tokenu zařízení",
    "Error while updating device token name" : "Chyba při aktualizaci názvu tokenu zařízení",
    "Error while deleting the token" : "Chyba při mazání tokenu",
    "Error while wiping the device with the token" : "Chyba při vymazávání zařízení s tokenem",
    "App name" : "Název aplikace",
    "Create new app password" : "Vytvořit nové heslo aplikace",
    "Use the credentials below to configure your app or device." : "Pro nastavení aplikace nebo zařízení použijte níže uvedené přihlašovací údaje.",
    "For security reasons this password will only be shown once." : "Toto heslo bude z bezpečnostních důvodů zobrazeno pouze jedenkrát.",
    "Username" : "Uživatelské jméno",
    "Password" : "Heslo",
    "Done" : "Dokončeno",
    "Show QR code for mobile apps" : "Zobrazit QR kód pro mobilní aplikace",
    "Copied!" : "Zkopírováno",
    "Copy" : "Zkopírovat",
    "Could not copy app password. Please copy it manually." : "Nedaří se zkopírovat heslo pro aplikaci. Zkopírujte ho ručně.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Pro správnou funkci serveru je důležité správně nastavit úlohy spouštěné na pozadí. Doporučenou metodou je použití systémového plánovače (cron). Další informace naleznete v dokumentaci.",
    "Last job execution ran {time}. Something seems wrong." : "Minulé vykonání úlohy bylo {time}. Zdá se, že něco není v pořádku.",
    "Last job ran {relativeTime}." : "Úloha minule běžela {relativeTime}.",
    "Background job did not run yet!" : "Úloha na pozadí ještě nebyla spuštěná!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single user instance." : "Vykonat jednu úlohu při každém načtení stránky. Příklad použití: instance pro jednoho uživatele.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php je zaregistrován u služby webcron aby přes HTTP volala cron.php každých 5 minut. Příklad použití: velmi malá instance (1-5 uživatelů, v závislosti na vytížení).",
    "Cron (Recommended)" : "Cron (doporučeno)",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Pro spuštění je potřeba PHP POSIX rozšíření. Více informací lze nalézt v {linkstart}dokumentaci k PHP{linkend}.",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Použít systémový plánovač (cron) pro volání souboru cron.php každých 5 minut. Doporučeno pro všechny instance.",
    "The cron.php needs to be executed by the system user \"{user}\"." : "Je třeba, aby cron.php bylo spouštěno s právy systémového uživatele „{user}“.",
    "Unable to update background job mode" : "Nedaří se aktualizovat režim úlohy běžící na pozadí",
    "Profile" : "Profil",
    "Enable or disable profile by default for new users." : "Profily nově vytvářených uživatelů ve výchozím stavu zpřístupňovat nebo nezpřístupňovat.",
    "Enable" : "Zapnout",
    "Unable to update profile default setting" : "Nedaří se aktualizovat výchozí nastavení pro profily",
    "Server-side encryption" : "Šifrování na straně serveru",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Šifrování na straně serveru umožňuje zašifrovat soubory, které jsou na tento server nahrávány. To přináší omezení jako třeba snížení výkonu, takže toto zapněte jen pokud je opravdu potřeba.",
    "Enable server-side encryption" : "Šifrovat na straně serveru",
    "Please read carefully before activating server-side encryption:" : "Důkladně si pročtěte a až teprve poté případně zapínejte šifrování dat na straně serveru:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Poté co je zapnuto šifrování, jsou od toho bodu všechny nahrávané soubory šifrovány serverem. Vypnout šifrování bude možné pouze později, až bude šifrovací modul tuto možnost podporovat a po splnění všech nutných podmínek (tzn. nastavení klíčů pro obnovení).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Šifrování samotné ještě nezaručuje bezpečnost systému. Pokud se chcete dozvědět víc o tom, jak aplikace pro šifrování funguje a jaké jsou podporované případy použití, naleznete to v dokumentaci.",
    "Be aware that encryption always increases the file size." : "Mějte na paměti, že šifrování vždy navýší velikost souboru.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Je vždy dobré vytvářet pravidelné zálohy svých dat, v případě zapnutého šifrování také zajistěte zálohu šifrovacích klíčů společně se zálohou dat.",
    "This is the final warning: Do you really want to enable encryption?" : "Toto je poslední varování: Opravdu chcete zapnout šifrování?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nenačten žádný šifrovací modul – zapněte ho v nabídce aplikace.",
    "Select default encryption module:" : "Vyberte výchozí šifrovací modul:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Je třeba přenést své šifrovací klíče ze staré verze šifrování (ownCloud <= 8.0) na novou. Zapněte „Výchozí modul šifrování“ a spusťte příkaz {command}",
    "Unable to update server side encryption config" : "Nedaří se zaktualizovat nastavení šifrování na straně serveru",
    "Rename group" : "Přejmenovat skupinu",
    "Remove group" : "Odebrat skupinu",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Chystáte se smazat skupinu {group}. Uživatelé NEbudou smazáni.",
    "Please confirm the group removal " : "Potvrďte odstranění skupiny",
    "Current password" : "Stávající heslo",
    "New password" : "Nové heslo",
    "Change password" : "Změnit heslo",
    "Your profile picture" : "Váš profilový obrázek",
    "Upload profile picture" : "Nahrát profilový obrázek",
    "Choose profile picture from files" : "Zvolit profilový obrázek ze souborů",
    "Remove profile picture" : "Odebrat profilový obrázek",
    "png or jpg, max. 20 MB" : "png nebo jpg, nejvýše 20 MB",
    "Picture provided by original account" : "Obrázek poskytovaný původním účtem",
    "Cancel" : "Storno",
    "Set as profile picture" : "Nastavit jako profilový obrázek",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Mějte na paměti, že může trvat až 24 hodin, než bude váš profilový obrázek aktualizován všude.",
    "Choose your profile picture" : "Vyberte si svůj profilový obrázek",
    "Please select a valid png or jpg file" : "Vyberte platný png nebo jpg soubor",
    "Error setting profile picture" : "Chyba při nastavování profilového obrázku",
    "Error cropping profile picture" : "Chyba při ořezávání profilového obrázku",
    "Error saving profile picture" : "Chyba při ukládání profilového obrázku",
    "Error removing profile picture" : "Chyba při odebírání profilového obrázku",
    "Your biography" : "Váš životopis",
    "Details" : "Podrobnosti",
    "You are a member of the following groups:" : "Jste členy následujících skupin:",
    "You are using <strong>{usage}</strong>" : "Využíváte <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Využíváte <strong>{usage}</strong> z <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "Your full name" : "Vaše celé jméno",
    "Email options" : "Předvolby e-mailu",
    "Primary email for password reset and notifications" : "Hlavní e-mail pro resetování hesla a oznamování",
    "Remove primary email" : "Odebrat hlavní e-mail",
    "Delete email" : "Smazat e-mail",
    "Unset as primary email" : "Zrušeno nastavení coby hlavního e-mailu",
    "This address is not confirmed" : "Z této adresy jste ještě nepotvrdili ověřovací e-mail",
    "Set as primary email" : "Nastavit jako hlavní e-mail",
    "Your email address" : "Vaše e-mailová adresa",
    "Additional email address {index}" : "Další e-mailová adresa {index}",
    "Unable to delete primary email address" : "Nepodařilo se smazat hlavní e-mailovou adresu",
    "Unable to update primary email address" : "Nepodařilo se aktualizovat hlavní e-mailovou adresu",
    "Unable to add additional email address" : "Nepodařilo se přidat další e-mailovou adresu",
    "Unable to update additional email address" : "Nepodařilo se aktualizovat další e-mailovou adresu",
    "Unable to delete additional email address" : "Nepodařilo se smazat další e-mailovou adresu",
    "No email address set" : "E-mailová adresa není nastavena",
    "Additional emails" : "Další e-maily",
    "Your headline" : "Váš nadpis",
    "Language" : "Jazyk",
    "Help translate" : "Pomoci s překladem",
    "Unable to update language" : "Jazyk se nedaří aktualizovat",
    "No language set" : "Není nastaven jazyk",
    "Locale" : "Místní a jazyková nastavení",
    "Week starts on {firstDayOfWeek}" : "Týden začíná {firstDayOfWeek}",
    "Unable to update locale" : "Nedaří se aktualizovat místní a jazyková nastavení",
    "No locale set" : "Nenastaveno žádné místní a jazykové nastavení",
    "Your location" : "Kde se nacházíte",
    "Your organisation" : "Vaše organizace",
    "Your phone number" : "Vaše telefonní číslo",
    "Edit your Profile visibility" : "Upravit viditelnost profilu",
    "Enable Profile" : "Zapnout profil",
    "Unable to update profile enabled state" : "Nedaří se aktualizovat stav zapnutí profilu",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Ohledně vašeho profilu bude respektována to více omezující nastavení – například, pokud je viditelnost nastavená na „Zobrazit všem“ a rozsah je nastavený na „Soukromé“, je respektováno „Soukromé.",
    "{displayId}" : "{displayId}",
    "Unable to update visibility of {displayId}" : "Nedaří se aktualizovat viditelnost {displayId}",
    "Your role" : "Vaše úloha",
    "Your Twitter handle" : "Twitter účet",
    "Your website" : "Vlastní webová stránka",
    "No {property} set" : "Nenastaveno žádné {property}",
    "Unable to update {property}" : "Nedaří se aktualizovat {property}",
    "Change scope level of {property}, current scope is {scope}" : "Změnit stupeň rozsahu {property}, stávající je {scope}",
    "Unable to update federation scope of the primary {property}" : "Nedaří se aktualizovat rozsah federování primární {property}",
    "Unable to update federation scope of additional {property}" : "Nedaří se aktualizovat rozsah federování dodatečné {property}",
    "Add additional email" : "Přidat další e-mail",
    "Add" : "Přidat",
    "You do not have permissions to see the details of this user" : "Nemáte oprávnění zobrazit si podrobností o tomto uživateli",
    "Add new password" : "Přidat nové heslo",
    "Add new email address" : "Přidat novou e-mailovou adresu",
    "Add user to group" : "Přidat uživatele do skupiny",
    "Set user as admin for" : "Nastavit uživatele jako správce pro",
    "Select user quota" : "Vybrat kvótu uživatele",
    "Delete user" : "Smazat uživatele",
    "Wipe all devices" : "Vymazat obsah ze všech zařízení",
    "Disable user" : "Znepřístupnit uživatelský účet",
    "Enable user" : "Zpřístupnit uživatelský účet",
    "Resend welcome email" : "Znovu poslat uvítací e-mail",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "V případě ztráty zařízení, nebo např. odchodu z firmy, toto může vzdáleně vymazat Nextcloud data ze všech zařízení asociovaných s uživatelem {userid}. Funguje jen pokud se zařízení připojí k Internetu.",
    "Remote wipe of devices" : "Vymazat obsah zařízení na dálku",
    "Wipe {userid}'s devices" : "Vymazat obsah ze zařízení uživatele {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Úplně vymazat účet {userid}, včetně veškerých osobní souborů, dat aplikací, atd.",
    "Account deletion" : "Smazání účtu",
    "Delete {userid}'s account" : "Smazat účet {userid}",
    "Welcome mail sent!" : "Uvítací e-mail odeslán!",
    "Edit User" : "Upravit uživatele",
    "Toggle user actions menu" : "Vyp/zap. nabídku akcí uživatele",
    "{size} used" : "{size} použito",
    "New user" : "Nový uživatel",
    "Will be autogenerated" : "Bude automaticky vytvořeno",
    "Display name" : "Zobrazované jméno",
    "Email" : "E-mail",
    "Default language" : "Výchozí jazyk",
    "Add a new user" : "Přidat nového uživatele",
    "Group admin for" : "Správce skupiny",
    "Quota" : "Kvóta",
    "User backend" : "Podpůrná vrstva pro uživatelské účty",
    "Storage location" : "Úložiště dat",
    "Last login" : "Poslední přihlášení",
    "No users in here" : "Nejsou zde žádní uživatelé",
    "Default quota" : "Výchozí kvóta",
    "Common languages" : "Běžné jazyky",
    "Other languages" : "Ostatní jazyky",
    "Password change is disabled because the master key is disabled" : "Změna hesla je vypnutá protože je vypnutý hlavní klíč",
    "Passwordless authentication requires a secure connection." : "Ověřování se bez hesla vyžaduje zabezpečené připojení.",
    "Add WebAuthn device" : "Přidat WebAuthn zařízení",
    "Please authorize your WebAuthn device." : "Udělte pověření vámi využívanému WebAuthn zařízení.",
    "Name your device" : "Nazvěte své zařízení",
    "Adding your device …" : "Přidávání zařízení…",
    "Server error while trying to add WebAuthn device" : "Chyba serveru při pokusu o přidání WebAuthn zařízení",
    "Server error while trying to complete WebAuthn device registration" : "Chyba serveru při pokusu o dokončení registrace WebAuthn zařízení",
    "Unnamed device" : "Nepojmenované zařízení",
    "Passwordless Authentication" : "Ověřování se bez zadávání hesla",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Nastavte svůj účet pro využívání ověřování se bez hesla pomocí standardu FIDO2.",
    "No devices configured." : "Není nastavené žádné zařízení.",
    "The following devices are configured for your account:" : "U svého účtu máte nastavená následující zařízení:",
    "Your browser does not support WebAuthn." : "Vámi používaný prohlížeč nepodporuje WebAuthn.",
    "Your apps" : "Vaše aplikace",
    "Active apps" : "Aktivní aplikace",
    "Disabled apps" : "Vypnuté aplikace",
    "Updates" : "Aktualizace",
    "App bundles" : "Sady aplikací",
    "Featured apps" : "Doporučené aplikace",
    "{license}-licensed" : "licencováno pod {license}",
    "Changelog" : "Souhrn změn",
    "by {author}\n{license}" : "od {author}\n{license}",
    "Enter group name" : "Zadejte název skupiny",
    "Add group" : "Přidat skupinu",
    "Active users" : "Aktivní uživatelé",
    "Admins" : "Správci",
    "Disabled users" : "Znepřístupnění uživatelé",
    "Default quota:" : "Výchozí kvóta:",
    "Select default quota" : "Vybrat výchozí kvótu",
    "Show Languages" : "Zobrazit jazyky",
    "Show last login" : "Zobrazit poslední přihlášení",
    "Show user backend" : "Zobrazit podpůrnou vrstvu pro uživatelské účty",
    "Show storage path" : "Zobrazit popis umístění úložiště",
    "Send email to new user" : "Poslat novému uživateli e-mail",
    "Not saved" : "Neuloženo",
    "Sending…" : "Odesílání…",
    "Email sent" : "E-mail odeslán",
    "Location" : "Poloha",
    "Profile picture" : "Profilový obrázek",
    "About" : "O uživateli",
    "Full name" : "Celé jméno",
    "Additional email" : "Další e-mail",
    "Headline" : "Nadpis",
    "Organisation" : "Organizace",
    "Phone number" : "Telefonní číslo",
    "Role" : "Role",
    "Twitter" : "Twitter",
    "Website" : "Webová stránka",
    "Profile visibility" : "Viditelnost profilu",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Není k dispozici, protože tato vlastnost je vyžadována pro  hlavní funkce, včetně sdílení souborů a pozvánek v kalendáři",
    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Není k dispozici protože pro váš účet bylo federování vypnuto. V případě dotazů se obraťte na svého správce",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Není k dispozici protože zveřejňování údajů o konkrétních uživatelích není vyhledávacímu serveru povoleno. Pokud máte jakékoli dotazy, obraťte se na správce systémů",
    "Show to everyone" : "Ukázat všem",
    "Show to logged in users only" : "Ukázat pouze přihlášeným uživatelům",
    "Hide" : "Skrýt",
    "Download and enable" : "Stáhnout a zapnout",
    "Enable untested app" : "Zapnout nevyzkoušenou aplikaci",
    "The app will be downloaded from the App Store" : "Aplikace bude stažena z katalogu aplikací",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Tato aplikace není označena jako kompatibilní s vámi používanou verzí Nexcloud. Pokud budete pokračovat, pořád budete moci aplikaci nainstalovat. Uvědomte si ale, že aplikace nemusí fungovat, jak je očekáváno.",
    "Never" : "Nikdy",
    "An error occurred during the request. Unable to proceed." : "Během požadavku došlo k chybě. Nelze pokračovat.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikace byla zapnuta ale je třeba ji ještě aktualizovat. Za 5 sekund budete přesměrování na stránku pro aktualizaci.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Chyba: tuto aplikaci nelze zapnout, protože způsobuje nestabilitu serveru",
    "Administrator documentation" : "Dokumentace pro správce",
    "Documentation" : "Dokumentace",
    "Forum" : "Diskuzní fórum",
    "Login" : "Přihlásit",
    "Plain" : "V čitelné podobě",
    "NT LAN Manager" : "Správce NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "Otevřít dokumentaci",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Je důležité tento server nastavit, aby mohly být odesílány e-maily, jako jsou např. ty pro resetování hesla a s upozorněními.",
    "Send mode" : "Režim odesílání",
    "Encryption" : "Šifrování",
    "Sendmail mode" : "Režim sendmail",
    "From address" : "Adresa odesílatele",
    "Authentication method" : "Metoda ověření",
    "Authentication required" : "Vyžadováno ověření se",
    "Server address" : "Adresa serveru",
    "Port" : "Port",
    "Credentials" : "Přihlašovací údaje",
    "SMTP Username" : "SMTP uživatelské jméno ",
    "SMTP Password" : "Heslo pro SMTP",
    "Save" : "Uložit",
    "Test and verify email settings" : "Vyzkoušet a ověřit nastavení e-mailu",
    "Send email" : "Odeslat e-mail",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Pro zabezpečení a optimální výkon instance Nextcloud je důležité, aby vše bylo správně nastaveno. Jako pomoc, instance samotná automaticky ověřuje některá nastavení. Další informace naleznete v odkazované dokumentaci.",
    "All checks passed." : "Všechny kontroly dopadly dobře.",
    "There are some errors regarding your setup." : "Jsou zde nějaké chyby ohledně vašeho nastavení.",
    "There are some warnings regarding your setup." : "Jsou zde nějaká varování ohledně vašeho nastavení.",
    "Checking for system and security issues." : "Kontrola systému a problémů se zabezpečením.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Důkladně si přečtěte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">průvodce instalací ↗</a> a zkontrolujte, že v <a href=\"%2$s\">záznamu událostí</a> nejsou žádné chyby ani varování.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Zkontrolujte zabezpečení svého Nextcloud přes <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">náš skener zabezpečení ↗</a>.",
    "Version" : "Verze",
    "You need to enable the File sharing App." : "Je třeba zapnout aplikaci pro sdílení souborů.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Jako správce můžete upravit chování sdílení. Více informací naleznete v dokumentaci.",
    "Allow apps to use the Share API" : "Umožnit aplikacím používat aplikační program. rozhraní (API) pro práci se sdíleními",
    "Set default expiration date for shares" : "Nastavit výchozí datum skončení platnosti pro sdílení",
    "Expire after" : "Platnost skončí po",
    "day(s)" : "dnů",
    "Enforce expiration date" : "Vynutit datum skončení platnosti",
    "Set default expiration date for shares to other servers" : "Nastavit výchozí datum skončení platnosti pro sdílení na jiné servery",
    "Allow users to share via link and emails" : "Povolit uživatelům sdílet pomocí odkazů a e-mailů",
    "Allow public uploads" : "Povolit veřejné nahrávání souborů",
    "Always ask for a password" : "Vždy se zeptat na heslo",
    "Enforce password protection" : "Vynutit ochranu heslem",
    "Exclude groups from password requirements:" : "Z požadavků na heslo vynechat následující skupiny:",
    "Set default expiration date" : "Nastavit výchozí datum skončení platnosti",
    "Exclude groups from creating link shares:" : "Vyjmout skupiny z možnosti vytváření sdílení odkazem:",
    "Allow resharing" : "Povolit příjemcům tohoto sdílení, aby sami mohli sdílet dalším",
    "Allow sharing with groups" : "Povolit sdílení se skupinami",
    "Restrict users to only share with users in their groups" : "Povolit sdílení pouze mezi uživateli v rámci skupiny",
    "Exclude groups from sharing" : "Vyjmout skupiny ze sdílení",
    "These groups will still be able to receive shares, but not to initiate them." : "Těmto skupinám bude stále možné sdílet, nemohou ale samy sdílet ostatním.",
    "Allow username autocompletion in share dialog" : "Povolit automatické dokončování uživatelského jména v dialogu pro sdílení",
    "Allow username autocompletion to users within the same groups" : "Umožnit automatické dokončování uživatelského jména uživatelům v rámci stejných skupin",
    "Allow username autocompletion to users based on phone number integration" : "Umožnit doplňování uživatelského jména uživatelům na základě začlenění telefonním číslem",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "V případě, že jsou zapnuté automatická dokončování „stejná skupina“ a „začlenění telefonním číslem“, postačí pro zobrazení uživatele shoda s jedním z toho.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Povolit automatické dokončování při zadávání celého jména nebo e-mailové adresy (při ignorování chybějící shody s telefonním seznamem a toho, že je ve stejné skupině)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Zobrazit text zřeknutí se odpovědnosti na stránce pro nahrání veřejného odkazu. (zobrazit pouze pokud je seznam souborů skrytý)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Tento text bude zobrazen on stránce pro nahrání veřejného odkazu, pokud bude seznam souborů skrytý.",
    "Default share permissions" : "Výchozí oprávnění sdílení",
    "Reasons to use Nextcloud in your organization" : "Důvody proč používat Nextcloud ve vaší organizaci",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Vyvíjeno {communityopen}komunitou Nextcloud{linkclose}, {githubopen}zdrojové kódy{linkclose} jsou licencovány pod {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Hodnoťte naše stránky na Facebooku",
    "Follow us on Twitter" : "Následujte nás na Twitteru",
    "Follow us on Mastodon" : "Následujte nás na Mastodon",
    "Check out our blog" : "Čtete náš blog",
    "Subscribe to our newsletter" : "Přihlaste se k odběru našeho zpravodaje",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Toto komunitní vydání Nextcloud není podporováno a okamžitá oznámení proto nejsou k dispozici",
    "Use a second factor besides your password to increase security for your account." : "Pro zlepšení zabezpečení vašeho účtu použijte vedle hesla také druhý faktor.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Pokud pro připojování se k Nextcloud používáte aplikace třetích stran, nezapomeňte před zapnutím ověřování druhým faktorem vytvořit pro jednotlivé aplikace jejich hesla.",
    "Migration in progress. Please wait until the migration is finished" : "Probíhá migrace. Vyčkejte jejího dokončení",
    "Migration started …" : "Migrace spuštěna…",
    "An error occurred while changing your language. Please reload the page and try again." : "Při změně jazyka došlo k chybě. Znovu načtěte stránku a zkuste to ještě jednou.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Došlo k chybě při změně místních a jazykových nastavení. Načtěte stránku znovu a zopakujte pokus.",
    "Select a profile picture" : "Vyberte profilový obrázek",
    "Week starts on {fdow}" : "Týden začíná v {fdow}",
    "Couldn't remove app." : "Aplikaci se nepodařilo odebrat.",
    "Couldn't update app." : "Aplikaci se nedaří aktualizovat.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Podpůrná vrstva nepodporuje změnu hesla, ale uživatelův šifrovací klíč byl aktualizován.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Nelze zjistit, zda je verze TLS cURL zastaralá nebo ne, protože během požadavku HTTPS na https://nextcloud.com došlo k chybě. Další podrobnosti najdete v souboru se záznamy událostí v Nextcloud.",
    "You need to set your user email before being able to send test emails." : "Pro možnost odeslání zkušebních e-mailů musíte nejprve nastavit svou e-mailovou adresu.",
    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Odstranění tohoto tokenu může zabránit vymazání obsahu přístroje, pokud nebyl proces vymazání do teď zahájen.",
    "Set as primary mail" : "Nastavit jako hlavní e-mai",
    "Change privacy level of email" : "Změnit úroveň soukromí e-mailu",
    "All languages" : "Všechny jazyky",
    "Everyone" : "Všichni",
    "An error occured during the request. Unable to proceed." : "Během požadavku došlo k chybě. Nelze pokračovat.",
    "Test email settings" : "Vyzkoušet nastavení e-mailu",
    "Please read carefully before activating server-side encryption: " : "Důkladně si pročtěte a až teprve poté případně zapínejte šifrování dat na straně serveru: ",
    "Enable encryption" : "Šifrovat",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Je třeba přenést své šifrovací klíče ze staré verze šifrování (ownCloud <= 8.0) na novou. Zapněte „Default encryption module“ a spusťte příkaz „occ encryption:migrate“",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Je třeba přenést své šifrovací klíče ze staré verze šifrování (ownCloud <= 8.0) na novou.",
    "Start migration" : "Zahájit migraci",
    "Last job execution ran %s. Something seems wrong." : "Minulá úloha byla vykonána: %s. Zdá se, že něco není v pořádku.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Některé úlohy nebyly vykonány už od %s. Zvažte zvýšení četnosti vykonávání.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Některé úlohy nebyly vykonány už od %s. Zvažte přepnutí na plánovač (cron) systému.",
    "Last job ran %s." : "Poslední úloha byla vykonána: %s.",
    "Background job didn’t run yet!" : "Úloha na pozadí ještě nebyla spuštěná!",
    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "Pro správnou funkci serveru je důležité správně nastavit úlohy spouštěné na pozadí. Doporučenou metodou je použití systémového plánovače (cron). Další informace naleznete v dokumentaci.",
    "Pick background job setting" : "Vybrat nastavení úlohy na pozadí",
    "Recommended" : "Doporučené",
    "The cron.php needs to be executed by the system user \"%s\"." : "Je třeba, aby cron.php bylo spouštěno s právy systémového uživatele „%s“.",
    "days" : "dnech",
    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Povolit automatické dokončování uživatelského jména při zadávání celého jména nebo e-mailové adresy (při ignorování chybějící shody s telefonním seznamem a toho, že je ve stejné skupině)",
    "Change privacy level of profile picture" : "Změnit úroveň soukromí profilového obrázku",
    "Upload new" : "Nahrát nový",
    "Select from Files" : "Vybrat ze Souborů",
    "Remove image" : "Odebrat obrázek",
    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Mějte na paměti, že může trvat až 24 hodin, než bude avatar aktualizován všude.",
    "Choose as profile picture" : "Vybrat jako profilový obrázek",
    "You are using <strong>%s</strong>" : "Vaše data zabírají <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Používáte <strong>%1$s</strong> z <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Change privacy level of full name" : "Změnit úroveň soukromí pro celé jméno",
    "No display name set" : "Nenastaveno žádné zobrazované jméno",
    "Change privacy level of phone number" : "Změnit úroveň soukromí telefonního čísla",
    "Address" : "Adresa",
    "Change privacy level of address" : "Změnit úroveň soukromí adresy",
    "Your postal address" : "Vaše poštovní adresa",
    "Change privacy level of website" : "Změnit úroveň soukromí webové stránky",
    "It can take up to 24 hours before the account is displayed as verified." : "Může trvat až 24 hodin, než se účet zobrazí jako ověřený.",
    "Link https://…" : "Odkaz https://…",
    "Change privacy level of Twitter profile" : "Změnit úroveň soukromí Twitteru",
    "Twitter handle @…" : "Přezdívka na Twitteru @…",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Je téměř vyčerpán nejvyšší umožněný počet klíčů v OPcache. Aby bylo zajištěno, že se do mezipaměti vejdou veškeré skripty, je doporučeno přidat do nastavení PHP volbu <code>opcache.max_accelerated_files</code> s hodnotou vyšší než <code>%s</code>.",
    "Admin privileges" : "Oprávnění správce",
    "Unable to update biography" : "Životopis se nedaří aktulizovat",
    "Unable to update full name" : "Nedaří se aktualizovat celé jméno",
    "No full name set" : "Nenastaveno celé jméno",
    "Unable to update headline" : "Nadpis se nedaří změnit",
    "Unable to update organisation" : "Nedaří se aktualizovat organizaci",
    "Unable to update role" : "Nedaří se aktualizovat roli",
    "Change scope level of {accountProperty}" : "Změnit stupeň rozsahu {accountProperty}",
    "Unable to update federation scope of the primary {accountProperty}" : "Nedaří se aktualizovat rozsah federování primární {accountProperty}",
    "Unable to update federation scope of additional {accountProperty}" : "Nedaří se aktualizovat rozsah federování dodatečné {accountProperty}",
    "Avatar" : "Profilový obrázek"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
